@@ -152,8 +152,12 @@ class EnvironmentInterface(ABC):
     @property
     def system_python(self):
         if self._system_python is None:
+            system_python = os.environ.get(AppEnvVars.PYTHON)
+            if system_python == 'self':
+                system_python = sys.executable
+
             system_python = (
-                os.environ.get(AppEnvVars.PYTHON)
+                system_python
                 or self.platform.modules.shutil.which('python')
                 or self.platform.modules.shutil.which('python3')
                 or sys.executable
@@ -270,7 +274,7 @@ class EnvironmentInterface(ABC):
             from packaging.requirements import InvalidRequirement, Requirement
 
             dependencies_complex = []
-            with self.metadata.context.apply_context(self.context):
+            with self.apply_context():
                 for option in ('dependencies', 'extra-dependencies'):
                     dependencies = self.config.get(option, [])
                     if not isinstance(dependencies, list):
@@ -306,16 +310,27 @@ class EnvironmentInterface(ABC):
     @property
     def dependencies_complex(self):
         if self._dependencies_complex is None:
-            dependencies_complex = list(self.environment_dependencies_complex)
+            all_dependencies_complex = list(self.environment_dependencies_complex)
 
             # Ensure these are checked last to speed up initial environment creation since
             # they will already be installed along with the project
             if not self.skip_install and self.dev_mode:
-                dependencies_complex.extend(self.metadata.core.dependencies_complex.values())
-                for feature in self.features:
-                    dependencies_complex.extend(self.metadata.core.optional_dependencies_complex[feature].values())
+                from hatch.utils.dep import get_project_dependencies_complex
 
-            self._dependencies_complex = dependencies_complex
+                dependencies_complex, optional_dependencies_complex = get_project_dependencies_complex(self)
+
+                all_dependencies_complex.extend(dependencies_complex.values())
+
+                for feature in self.features:
+                    if feature not in optional_dependencies_complex:
+                        raise ValueError(
+                            f'Feature `{feature}` of field `tool.hatch.envs.{self.name}.features` is not '
+                            f'defined in the dynamic field `project.optional-dependencies`'
+                        )
+
+                    all_dependencies_complex.extend(optional_dependencies_complex[feature].values())
+
+            self._dependencies_complex = all_dependencies_complex
 
         return self._dependencies_complex
 
@@ -425,6 +440,7 @@ class EnvironmentInterface(ABC):
             if not isinstance(features, list):
                 raise TypeError(f'Field `tool.hatch.envs.{self.name}.features` must be an array of strings')
 
+            dynamic_features = 'optional-dependencies' in self.metadata.dynamic
             all_features = set()
             for i, feature in enumerate(features, 1):
                 if not isinstance(feature, str):
@@ -434,8 +450,9 @@ class EnvironmentInterface(ABC):
                         f'Feature #{i} of field `tool.hatch.envs.{self.name}.features` cannot be an empty string'
                     )
 
-                feature = normalize_project_name(feature)
-                if feature not in self.metadata.core.optional_dependencies:
+                if not self.metadata.hatch.metadata.allow_ambiguous_features:
+                    feature = normalize_project_name(feature)
+                if not dynamic_features and feature not in self.metadata.core.optional_dependencies:
                     raise ValueError(
                         f'Feature `{feature}` of field `tool.hatch.envs.{self.name}.features` is not '
                         f'defined in field `project.optional-dependencies`'
@@ -594,6 +611,10 @@ class EnvironmentInterface(ABC):
         This should perform the necessary steps to completely remove the environment from the system and will only
         be triggered manually by users with the [`env remove`](../../cli/reference.md#hatch-env-remove) or
         [`env prune`](../../cli/reference.md#hatch-env-prune) commands.
+
+        If the
+        [build environment](reference.md#hatch.env.plugin.interface.EnvironmentInterface.build_environment)
+        has a caching mechanism, this should remove that as well.
         """
 
     @abstractmethod
@@ -679,6 +700,14 @@ class EnvironmentInterface(ABC):
         """
         return self.platform.capture_process(self.construct_build_command(**kwargs))
 
+    def build_environment_exists(self):
+        """
+        If the
+        [build environment](reference.md#hatch.env.plugin.interface.EnvironmentInterface.build_environment)
+        has a caching mechanism, this should indicate whether or not it has already been created.
+        """
+        return False
+
     def enter_shell(self, name, path, args):
         """
         Spawn a [shell](../../config/hatch.md#shell) within the environment.
@@ -690,7 +719,7 @@ class EnvironmentInterface(ABC):
         with self.command_context():
             self.platform.exit_with_command([path, *args])
 
-    def run_shell_command(self, command: str):
+    def run_shell_command(self, command: str, **kwargs):
         """
         This should return the standard library's
         [subprocess.CompletedProcess](https://docs.python.org/3/library/subprocess.html#subprocess.CompletedProcess)
@@ -698,7 +727,8 @@ class EnvironmentInterface(ABC):
         [command_context](reference.md#hatch.env.plugin.interface.EnvironmentInterface.command_context)
         is active, with the expectation of providing the same guarantee.
         """
-        return self.platform.run_command(command, shell=True)
+        kwargs.setdefault('shell', True)
+        return self.platform.run_command(command, **kwargs)
 
     @contextmanager
     def command_context(self):
@@ -728,7 +758,7 @@ class EnvironmentInterface(ABC):
         if not args:
             args = None
 
-        with self.metadata.context.apply_context(self.context):
+        with self.apply_context():
             if possible_script in self.scripts:
                 for cmd in self.scripts[possible_script]:
                     yield self.metadata.context.format(cmd, args=args).strip()
@@ -849,6 +879,11 @@ class EnvironmentInterface(ABC):
         """
         return {}
 
+    @contextmanager
+    def apply_context(self):
+        with self.get_env_vars(), self.metadata.context.apply_context(self.context):
+            yield
+
     def __enter__(self):
         self.activate()
         return self
