@@ -92,6 +92,49 @@ class TestDynamic:
         assert metadata.core.dynamic is dynamic
         assert metadata.core.dynamic == ['version']
 
+    def test_cache_not_array(self, isolation):
+        metadata = ProjectMetadata(str(isolation), None, {'project': {'dynamic': 10}})
+
+        with pytest.raises(TypeError, match='Field `project.dynamic` must be an array'):
+            _ = metadata.dynamic
+
+    def test_cache_entry_not_string(self, isolation):
+        metadata = ProjectMetadata(str(isolation), None, {'project': {'dynamic': [10]}})
+
+        with pytest.raises(TypeError, match='Field #1 of field `project.dynamic` must be a string'):
+            _ = metadata.dynamic
+
+    def test_cache_correct(self, temp_dir, helpers):
+        metadata = ProjectMetadata(
+            str(temp_dir),
+            PluginManager(),
+            {
+                'project': {'name': 'foo', 'dynamic': ['version', 'description']},
+                'tool': {'hatch': {'version': {'path': 'a/b'}, 'metadata': {'hooks': {'custom': {}}}}},
+            },
+        )
+
+        file_path = temp_dir / 'a' / 'b'
+        file_path.ensure_parent_dir_exists()
+        file_path.write_text('__version__ = "0.0.1"')
+
+        file_path = temp_dir / DEFAULT_BUILD_SCRIPT
+        file_path.write_text(
+            helpers.dedent(
+                """
+                from hatchling.metadata.plugin.interface import MetadataHookInterface
+
+                class CustomHook(MetadataHookInterface):
+                    def update(self, metadata):
+                        metadata['description'] = metadata['name'] + 'bar'
+                """
+            )
+        )
+
+        # Trigger hooks with `metadata.core` first
+        assert metadata.core.dynamic == []
+        assert metadata.dynamic == ['version', 'description']
+
 
 class TestRawName:
     def test_dynamic(self, isolation):
@@ -503,6 +546,12 @@ class TestLicense:
 
         assert metadata.core.license_expression == 'MIT OR Apache-2.0'
 
+    def test_invalid_expression(self, isolation):
+        metadata = ProjectMetadata(str(isolation), None, {'project': {'license': 'mit or foo'}})
+
+        with pytest.raises(ValueError, match='Error parsing field `project.license` - unknown license: foo'):
+            _ = metadata.core.license_expression
+
     def test_multiple_options(self, isolation):
         metadata = ProjectMetadata(str(isolation), None, {'project': {'license': {'file': '', 'text': ''}}})
 
@@ -1247,6 +1296,18 @@ class TestOptionalDependencies:
         ):
             _ = metadata.core.optional_dependencies
 
+    def test_allow_ambiguity(self, isolation):
+        metadata = ProjectMetadata(
+            str(isolation),
+            None,
+            {
+                'project': {'optional-dependencies': {'foo_bar': [], 'foo.bar': []}},
+                'tool': {'hatch': {'metadata': {'allow-ambiguous-features': True}}},
+            },
+        )
+
+        assert metadata.core.optional_dependencies == {'foo_bar': [], 'foo.bar': []}
+
     def test_direct_reference(self, isolation):
         metadata = ProjectMetadata(
             str(isolation),
